@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -34,6 +35,18 @@
 int fsync (int fd) { return 0; }
 #endif
 
+
+/**
+ * SECTION: gmime-stream-fs
+ * @title: GMimeStreamFs
+ * @short_description: A low-level FileSystem stream
+ * @see_also: #GMimeStream
+ *
+ * A simple #GMimeStream implementation that sits on top of the
+ * low-level UNIX file descriptor based I/O layer.
+ **/
+
+
 static void g_mime_stream_fs_class_init (GMimeStreamFsClass *klass);
 static void g_mime_stream_fs_init (GMimeStreamFs *stream, GMimeStreamFsClass *klass);
 static void g_mime_stream_fs_finalize (GObject *object);
@@ -44,10 +57,10 @@ static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
 static int stream_reset (GMimeStream *stream);
-static off_t stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-static off_t stream_tell (GMimeStream *stream);
+static gint64 stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
+static gint64 stream_tell (GMimeStream *stream);
 static ssize_t stream_length (GMimeStream *stream);
-static GMimeStream *stream_substream (GMimeStream *stream, off_t start, off_t end);
+static GMimeStream *stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
 
 static GMimeStreamClass *parent_class = NULL;
@@ -129,10 +142,10 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 		return -1;
 	
 	if (stream->bound_end != -1)
-		len = MIN (stream->bound_end - stream->position, (off_t) len);
+		len = MIN (stream->bound_end - stream->position, (gint64) len);
 	
 	/* make sure we are at the right position */
-	lseek (fs->fd, stream->position, SEEK_SET);
+	lseek (fs->fd, (off_t) stream->position, SEEK_SET);
 	
 	do {
 		nread = read (fs->fd, buf, len);
@@ -157,10 +170,10 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 		return -1;
 	
 	if (stream->bound_end != -1)
-		len = MIN (stream->bound_end - stream->position, (off_t) len);
+		len = MIN (stream->bound_end - stream->position, (gint64) len);
 	
 	/* make sure we are at the right position */
-	lseek (fs->fd, stream->position, SEEK_SET);
+	lseek (fs->fd, (off_t) stream->position, SEEK_SET);
 	
 	do {
 		do {
@@ -235,7 +248,7 @@ stream_reset (GMimeStream *stream)
 	/* FIXME: if stream_read/write is always going to lseek to
 	 * make sure fd's seek position matches our own, we could just
 	 * set stream->position = stream->bound_start and be done. */
-	if (lseek (fs->fd, stream->bound_start, SEEK_SET) == -1)
+	if (lseek (fs->fd, (off_t) stream->bound_start, SEEK_SET) == -1)
 		return -1;
 	
 	fs->eos = FALSE;
@@ -243,11 +256,11 @@ stream_reset (GMimeStream *stream)
 	return 0;
 }
 
-static off_t
-stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
+static gint64
+stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 {
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
-	off_t real;
+	gint64 real;
 	
 	g_return_val_if_fail (fs->fd != -1, -1);
 	
@@ -264,7 +277,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 			 * we either don't know the offset of the end
 			 * of the stream and/or don't know if we can
 			 * seek past the end */
-			if ((real = lseek (fs->fd, offset, SEEK_END)) == -1)
+			if ((real = lseek (fs->fd, (off_t) offset, SEEK_END)) == -1)
 				return -1;
 		} else if (fs->eos && stream->bound_end == -1) {
 			/* seeking backwards from eos (which happens
@@ -292,7 +305,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 	if (stream->bound_end != -1 && real > stream->bound_end)
 		return -1;
 	
-	if ((real = lseek (fs->fd, real, SEEK_SET)) == -1)
+	if ((real = lseek (fs->fd, (off_t) real, SEEK_SET)) == -1)
 		return -1;
 	
 	/* reset eos if appropriate */
@@ -305,7 +318,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 	return real;
 }
 
-static off_t
+static gint64
 stream_tell (GMimeStream *stream)
 {
 	return stream->position;
@@ -315,13 +328,13 @@ static ssize_t
 stream_length (GMimeStream *stream)
 {
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
-	off_t bound_end;
+	gint64 bound_end;
 	
 	if (stream->bound_end != -1)
 		return stream->bound_end - stream->bound_start;
 	
-	bound_end = lseek (fs->fd, 0, SEEK_END);
-	lseek (fs->fd, stream->position, SEEK_SET);
+	bound_end = lseek (fs->fd, (off_t) 0, SEEK_END);
+	lseek (fs->fd, (off_t) stream->position, SEEK_SET);
 	
 	if (bound_end < stream->bound_start)
 		return -1;
@@ -330,7 +343,7 @@ stream_length (GMimeStream *stream)
 }
 
 static GMimeStream *
-stream_substream (GMimeStream *stream, off_t start, off_t end)
+stream_substream (GMimeStream *stream, gint64 start, gint64 end)
 {
 	GMimeStreamFs *fs;
 	
@@ -350,15 +363,15 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
  *
  * Creates a new GMimeStreamFs object around @fd.
  *
- * Returns a stream using @fd.
+ * Returns: a stream using @fd.
  **/
 GMimeStream *
 g_mime_stream_fs_new (int fd)
 {
 	GMimeStreamFs *fs;
-	off_t start;
+	gint64 start;
 	
-	if ((start = lseek (fd, 0, SEEK_CUR)) == -1)
+	if ((start = lseek (fd, (off_t) 0, SEEK_CUR)) == -1)
 		start = 0;
 	
 	fs = g_object_new (GMIME_TYPE_STREAM_FS, NULL);
@@ -380,10 +393,10 @@ g_mime_stream_fs_new (int fd)
  * Creates a new GMimeStreamFs object around @fd with bounds @start
  * and @end.
  *
- * Returns a stream using @fd with bounds @start and @end.
+ * Returns: a stream using @fd with bounds @start and @end.
  **/
 GMimeStream *
-g_mime_stream_fs_new_with_bounds (int fd, off_t start, off_t end)
+g_mime_stream_fs_new_with_bounds (int fd, gint64 start, gint64 end)
 {
 	GMimeStreamFs *fs;
 	
@@ -403,7 +416,7 @@ g_mime_stream_fs_new_with_bounds (int fd, off_t start, off_t end)
  *
  * Gets whether or not @stream owns the backend file descriptor.
  *
- * Returns %TRUE if @stream owns the backend file descriptor or %FALSE
+ * Returns: %TRUE if @stream owns the backend file descriptor or %FALSE
  * otherwise.
  **/
 gboolean
